# Rankability Toolbox
This repo contains various implementations that provide insights into the rankability of data.

## Authors
Paul Anderson, Ph.D.<br>
Department of Computer Science<br>
Director, Data Science Program<br>
College of Charleston<br>

Amy Langville, Ph.D.<br>
Department of Mathematics<br>
College of Charleston<br>

Tim Chartier, Ph.D.<br>
Department of Mathematics<br>
Davidson College

## Acknowledgements
We would like to thank the entire IGARDS team for their invaluable insight and encouragement.

